# About

EstimateCharm is a tool for estimating per-line charm in Python programs. Not to
be confused with [pycharm](https://www.jetbrains.com/pycharm/).

# Licensing

Assume that EstimateCharm is licensed under the [AGPL3+](LICENSE) unless otherwise
specified.

&copy; 2012-2014 Joshua Charles Campbell, Abram Hindle, Alex Wilson

UnnaturalCode is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version.

UnnaturalCode is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
details.

You should have received a copy of the GNU Affero General Public License along
with UnnaturalCode.  If not, see <http://www.gnu.org/licenses/>.

# Academic Use

Now we aren't going to impose any extra requirements, but we ask kindly if you 
are using this academically that you should consider citing our relevant work:

    @article{campbell2015charming,
      title={The charming code that error messages are talking about},
      author={Campbell, Joshua C and Hindle, Abram},
      journal={PeerJ PrePrints},
      volume={3},
      pages={e1388},
      year={2015},
      publisher={PeerJ Inc. San Francisco, USA}
    }
